@@ -7,6 +7,7 @@ predict.rfsrc <-
            block.size = if (any(is.element(as.character(importance), c("none", "FALSE")))) NULL else 10,
            na.action = c("na.omit", "na.impute"),
            outcome = c("train", "test"),
+           perf.type = NULL,
            proximity = FALSE,
            forest.wt = FALSE,
            ptn.count = 0,
@@ -28,6 +29,7 @@ predict.rfsrc <-
                                           block.size = block.size,
                                           na.action = na.action,
                                           outcome = outcome,
+                                          perf.type = perf.type,
                                           proximity = proximity,
                                           forest.wt = forest.wt,
                                           ptn.count = ptn.count,
